@@ -2,6 +2,11 @@
 //!
 //! A weighted random sampling crate using Walker's Alias Method.
 //!
+//! Walker's Alias Method (WAM) is one method for performing weighted
+//! random sampling. WAM weights each index of a array by giving two
+//! pieces of information: an alias to a different index and a threshold
+//! (or a probability) to decide whether to jump to that index.
+//!
 //! ## Example
 //!
 //! ```rust
@@ -10,16 +15,15 @@
 //! fn main() {
 //!     let fruit = ["Apple", "Banana", "Orange", "Peach"];
 //!
-//!     // The weights of the output indexes.
-//!     // The higher the weight, the more likely the corresponding index will be
-//!     // output.
-//!     // In the following case, the output probabilities for each index are 0.2,
-//!     // 0.1, 0.7 and 0. If a weight value is 0, the corresponding index will not
-//!     // be output. In other words, the index 3 will not be output in this case.
+//!     // Define the weights for each index corresponding
+//!     // to the above list.
+//!     // In the following case, the ratio of each weight
+//!     // is "2 : 1 : 7 : 0", and the output probabilities
+//!     // for each index are 0.2, 0.1, 0.7 and 0.
 //!     let index_weights = vec![2, 1, 7, 0];
 //!
 //!     let mut builder = WalkerTableBuilder::new(index_weights);
-//!     let wa_table = builder.build().unwrap();
+//!     let wa_table = builder.build();
 //!
 //!     for _ in 0..10 {
 //!         let i = wa_table.next(); // Will output 0, 1, or 2
@@ -30,5 +34,4 @@
 //!
 
 pub mod builder;
-pub mod error;
 pub mod table;
